<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>CustomAutoAnnotationDialog</name>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="14"/>
        <source>Plasmid Auto Annotations</source>
        <translation>Поиск плазмид</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="20"/>
        <source>Selected features</source>
        <translation>Выбранные аннотации</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="26"/>
        <source>Promoter</source>
        <translation>Promoter</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="33"/>
        <source>Origin</source>
        <translation>Origin</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="40"/>
        <source>Terminator</source>
        <translation>Terminator</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="47"/>
        <source>Primer</source>
        <translation>Primer</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="54"/>
        <source>Gene</source>
        <translation>Gene</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="61"/>
        <source>Other features</source>
        <translation>Другие аннотации</translation>
    </message>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.ui" line="68"/>
        <source>Regulatory</source>
        <translation>Regulatory</translation>
    </message>
</context>
<context>
    <name>FindAnnotationCollocationsDialog</name>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="58"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="63"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="96"/>
        <source>Region size:</source>
        <translation>Размер региона:</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="20"/>
        <source>Find Groups of Annotated Regions</source>
        <translation>Поиск сгруппированных аннотаций</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="158"/>
        <source>Save regions as annotations</source>
        <translation>Сохранить регионы как аннотации</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="165"/>
        <source>Clear results</source>
        <translation>Сбросить результаты</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="176"/>
        <source>Result strand</source>
        <translation>Расположение результатов</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="182"/>
        <source>Direct</source>
        <translation>Прямая</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="189"/>
        <source>Complement</source>
        <translation>Комплементарная</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="196"/>
        <source>Both</source>
        <translation>Обе</translation>
    </message>
    <message>
        <location filename="../src/FindAnnotationCollocationsDialog.ui" line="219"/>
        <source>Annotation must fit into region</source>
        <translation>Аннотация должна содержаться в регионе</translation>
    </message>
</context>
<context>
    <name>U2::AnnotatorPlugin</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="54"/>
        <source>DNA Annotator</source>
        <translation>Поиск сгруппированных аннотаций</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="54"/>
        <source>This plugin contains routines to manipulate and search DNA sequence annotations</source>
        <translation>Поиск сгруппированных аннотаций</translation>
    </message>
</context>
<context>
    <name>U2::AnnotatorViewContext</name>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="92"/>
        <source>Find annotated regions...</source>
        <translation>Поиск участков, соответствующих аннотации...</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="96"/>
        <source>Annotate plasmid...</source>
        <translation>Автоматический поиск плазмид...</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="117"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../src/AnnotatorPlugin.cpp" line="117"/>
        <source>No annotations found</source>
        <translation>Аннотаций не найдено</translation>
    </message>
</context>
<context>
    <name>U2::CollocationSearchTask</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="315"/>
        <location filename="../src/CollocationsDialogController.cpp" line="344"/>
        <source>Search for annotated regions</source>
        <translation>Поиск сгруппированных аннотаций</translation>
    </message>
</context>
<context>
    <name>U2::CollocationsDialogController</name>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="52"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="53"/>
        <location filename="../src/CollocationsDialogController.cpp" line="95"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="56"/>
        <source>&lt;&lt;click &apos;+&apos; button to add new annotation&gt;&gt;</source>
        <translation>&lt;&lt; Кликните &apos;+&apos; чтобы добавить аннотацию &gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="95"/>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="101"/>
        <source>Searching... found %1 regions. Progress: %2%</source>
        <translation>Сканируется последовательность, прогресс %2. Найдено %1 регионов</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="103"/>
        <source>Found %1 regions</source>
        <translation>Найдено %1 регионов</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="105"/>
        <source>Ready</source>
        <translation>Готов к поиску</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="105"/>
        <source>Select annotation names to search</source>
        <translation>Выберите аннотации</translation>
    </message>
    <message>
        <location filename="../src/CollocationsDialogController.cpp" line="125"/>
        <source>No annotations left</source>
        <translation>Аннотаций больше нет</translation>
    </message>
</context>
<context>
    <name>U2::CustomAutoAnnotationDialog</name>
    <message>
        <location filename="../src/CustomAutoAnnotationDialog.cpp" line="44"/>
        <source>Annotate</source>
        <translation>Аннотировать</translation>
    </message>
</context>
<context>
    <name>U2::CustomPatternAnnotationTask</name>
    <message>
        <location filename="../src/CustomPatternAnnotationTask.cpp" line="52"/>
        <source>Custom pattern annotation</source>
        <translation>Пользовательская аннотация</translation>
    </message>
    <message>
        <location filename="../src/CustomPatternAnnotationTask.cpp" line="112"/>
        <source>Object with annotations was removed</source>
        <translation>Объект с аннотациями был удалён</translation>
    </message>
</context>
<context>
    <name>U2::CustomPatternAutoAnnotationUpdater</name>
    <message>
        <location filename="../src/CustomPatternAnnotationTask.cpp" line="222"/>
        <source>Plasmid features</source>
        <translation>Аннотирование плазмид</translation>
    </message>
</context>
<context>
    <name>U2::GeneByGeneReportTask</name>
    <message>
        <location filename="../src/GeneByGeneReportTask.cpp" line="286"/>
        <source>Generating gene-by-gene approach report</source>
        <translation>Generating gene-by-gene approach report</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::CollocationPrompter</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="148"/>
        <source> sequence from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation> последовательности из &lt;u&gt;%1&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="151"/>
        <source> set of annotations from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation> набора аннотаций из &lt;u&gt;%1&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="158"/>
        <source>For each %1 and %2,</source>
        <translation>Для каждых %1 и %2,</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="160"/>
        <source>For each %1%2,</source>
        <translation>Для каждого %1%2,</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="176"/>
        <source> Annotations themselves may not span beyond the region.</source>
        <translation> целиком.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="180"/>
        <source>%1 look if &lt;u&gt;%2&lt;/u&gt; annotations appear collocated within same region of length &lt;u&gt;%3&lt;/u&gt;.%4&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation>%1 искать группы аннотаций &lt;u&gt;%2&lt;/u&gt; расположенные &lt;u&gt;%4&lt;/u&gt; внутри регионов не длиннее &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Выдать список найденных групп в виде аннотаций &quot;&lt;u&gt;%5&lt;/u&gt;&quot;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::CollocationWorker</name>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="92"/>
        <source>Group annotations</source>
        <translation>Найденные регионы</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="131"/>
        <source>Create new annotations</source>
        <translation>Создать новые аннотации</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="99"/>
        <source>Result annotation</source>
        <translation>Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="99"/>
        <source>Name of the result annotations to mark found collocations.</source>
        <translation>Имя результирующих аннотаций отмечающих найденные группы.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="100"/>
        <source>Group of annotations</source>
        <translation>Аннотации в группе</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="101"/>
        <source>Region size</source>
        <translation>Размер региона</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="101"/>
        <source>Effectively this is the maximum allowed distance between the interesting annotations in a group.</source>
        <translation>Фактически, это максимальная допустимая дистанция между аннотациями в одной группе.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="102"/>
        <source>Must fit into region</source>
        <translation>Компактные группы</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="102"/>
        <source>Whether the interesting annotations should entirely fit into the specified region to form a group.</source>
        <translation>Аннотации в группе должны целиком входить в указанный регион - т.е. дистанция в группе считается по внешним границам аннотаций.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="103"/>
        <source>Result type</source>
        <translation>Тип аннотации</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="103"/>
        <source>Copy original annotations or annotate found regions with new ones.</source>
        <translation>Копировать оригинальные аннотации или аннотировать найденные регионы новыми.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="104"/>
        <source>Include boundaries</source>
        <translation>Включить границы</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="104"/>
        <source>Include most left and most right boundary annotations regions into result or exclude them.</source>
        <translation>Включить границы региона в аннотацию или исключить их.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="119"/>
        <source>Collocation Search</source>
        <translation>Поиск групп аннотаций</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="130"/>
        <source>Copy original annotations</source>
        <translation>Копировать исходные аннотации</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="68"/>
        <source>At least 2 annotations are required for collocation search.</source>
        <translation>Необходимо указать не менее 2-х различных имён аннотаций для поиска.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="93"/>
        <source>Annotated regions containing found collocations.</source>
        <translation>Список аннотаций отмечающих найденные группы аннотаций.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="100"/>
        <source>A list of annotation names to search. Found regions will contain all the named annotations.</source>
        <translation>Список имён интересующих аннотаций в группе. Ищутся регионы содержащие все указанные аннотации.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="119"/>
        <source>Finds groups of specified annotations in each supplied set of annotations, stores found regions as annotations.</source>
        <translation>Поиск сгруппированных аннотаций. Ищутся регионы последовательности, содержащие все аннотации из заданного списка, расположенные друг от друга на расстоянии не более заданного.</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="88"/>
        <source>Input data</source>
        <translation>Входные данные</translation>
    </message>
    <message>
        <location filename="../src/CollocationWorker.cpp" line="88"/>
        <source>An input sequence and a set of annotations to search in.</source>
        <translation>Входные последовательность и набор аннотированных регионов для поиска.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::GeneByGeneReportPrompter</name>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="223"/>
        <source>unset</source>
        <translation>не указан</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="231"/>
        <source>For annotated genes from &lt;u&gt;%1&lt;/u&gt; build gene-by-gene approach report.</source>
        <translation>Для аннотированных генов из &lt;u&gt;%1&lt;/u&gt; построить приближенный отчет по каждому гену.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="232"/>
        <source> With sequence identity of &lt;u&gt;%1&lt;/u&gt;.</source>
        <translation> С идентичностью последовательности &lt;u&gt;%1&lt;/u&gt;.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="233"/>
        <source> Using &lt;u&gt;%1&lt;/u&gt; to compare gene and genome sequences.</source>
        <translation> Использовать &lt;u&gt;%1&lt;/u&gt; для сравнения гена и геномных последовательностей.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="234"/>
        <source> Output result table to &lt;u&gt;%1&lt;/u&gt;.</source>
        <translation> Выходная таблица в &lt;u&gt;%1&lt;/u&gt;.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="235"/>
        <source> If a report file already exists, &lt;u&gt;%1&lt;/u&gt; it</source>
        <translation> Если файл уже существует, &lt;u&gt;%1&lt;/u&gt; его</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::GeneByGeneReportWorker</name>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="145"/>
        <source>Input annotations</source>
        <translation>Входные аннотации</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="146"/>
        <source>Gene annotations.</source>
        <translation>Аннотации гена.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="149"/>
        <source>Input sequences</source>
        <translation>Входные последовательности</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="150"/>
        <source>Gene sequences.</source>
        <translation>Последовательности гена.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="154"/>
        <source>Gene by gene report data.</source>
        <translation>Отчетные данные.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="155"/>
        <source>Gene with similar regions to for report.</source>
        <translation>Ген со схожими регионами для отчета.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="163"/>
        <source>Output file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="164"/>
        <source>File to store a report.</source>
        <translation>Файл для сохранения отчета.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="166"/>
        <source>Annotation name</source>
        <translation>Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="167"/>
        <source>Annotation name used to compare genes and reference genomes.</source>
        <translation>Имя аннотации используемое для сравнения генов и референсных геномов.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="169"/>
        <source>Existing file</source>
        <translation>Существующий файл</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="170"/>
        <source>If a target report already exists you should specify how to handle that. &lt;b&gt;Merge&lt;/b&gt; two table in one. &lt;b&gt;Overwrite&lt;/b&gt; or &lt;b&gt;Rename&lt;/b&gt; existing file.</source>
        <translation>Если файл уже существует выберите операцию. &lt;b&gt;Соединить&lt;/b&gt; две таблицы в одну. &lt;b&gt;Переписать&lt;/b&gt; или &lt;b&gt;Переименовать&lt;/b&gt; существующий файл.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="173"/>
        <source>Identity cutoff</source>
        <translation>Сдвиг идентичности</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="174"/>
        <source>Identity between gene sequence length and annotation length in per cent. BLAST identity (if specified) is checked after.</source>
        <translation>Идентичность между длиной гена и длиной аннотации в процентах.</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="204"/>
        <source>Gene-by-gene Approach Report</source>
        <translation>Отчёт по каждому гену</translation>
    </message>
    <message>
        <location filename="../src/GeneByGeneReportWorker.cpp" line="205"/>
        <source>Output a table of genes found in a reference sequence.</source>
        <translation>Таблица генов найденных в референсной последовательности.</translation>
    </message>
</context>
</TS>
